%--------------------------------------------------------------------------
% File     : MGT020+1 : TPTP v2.1.0. Released v2.0.0.
% Domain   : Management (Organisation Theory)
% Problem  : First movers exceeds efficient producers disbanding rate
% Version  : [PB+94] axioms.
% English  : 

% Refs     : [PM93]  Peli & Masuch (1993), The Logic of Propogation Strateg
%          : [PM94]  Peli & Masuch (1994), The Logic of Propogation Strateg
%          : [Kam95] Kamps (1995), Email to G. Sutcliffe
% Source   : [Kam95]
% Names    : LEMMA 2 [PM93]
%          : L2 [PB+94]

% Status   : theorem
% Rating   : ? v2.0.0
% Syntax   : Number of formulae    :   32 (   1 unit)
%            Number of atoms       :   96 (  31 equality)
%            Maximal formula depth :    7 (   3 average)
%            Number of connectives :   66 (   2 ~  ;   1  |;  29  &)
%                                         (   0 <=>;  34 =>;   0 <=)
%                                         (   0 <~>;   0 ~|;   0 ~&)
%            Number of predicates  :    7 (   0 propositional; 1-4 arity)
%            Number of functors    :    6 (   2 constant; 0-2 arity)
%            Number of variables   :   90 (   0 singleton;  90 !;   0 ?)
%            Maximal term depth    :    3 (   1 average)

% Comments : Same as version with [PM93] axioms.
%--------------------------------------------------------------------------
%----Include equality axioms
include('Axioms/EQU001+0.ax').
%--------------------------------------------------------------------------
%----Subsitution axioms
input_formula(difference_substitution_1,axiom,(
    ! [A,B,C] : 
      ( equal(A,B)
     => equal(difference(A,C),difference(B,C)) )   )).

input_formula(difference_substitution_2,axiom,(
    ! [A,B,C] : 
      ( equal(A,B)
     => equal(difference(C,A),difference(C,B)) )   )).

input_formula(disbanding_rate_substitution_1,axiom,(
    ! [A,B,C] : 
      ( equal(A,B)
     => equal(disbanding_rate(A,C),disbanding_rate(B,C)) )   )).

input_formula(disbanding_rate_substitution_2,axiom,(
    ! [A,B,C] : 
      ( equal(A,B)
     => equal(disbanding_rate(C,A),disbanding_rate(C,B)) )   )).

input_formula(initial_FM_EP_substitution_1,axiom,(
    ! [A,B] : 
      ( equal(A,B)
     => equal(initial_FM_EP(A),initial_FM_EP(B)) )   )).

input_formula(start_time_substitution_1,axiom,(
    ! [A,B] : 
      ( equal(A,B)
     => equal(start_time(A),start_time(B)) )   )).

input_formula(decreases_substitution_1,axiom,(
    ! [A,B] : 
      ( ( equal(A,B)
        & decreases(A) )
     => decreases(B) )   )).

input_formula(environment_substitution_1,axiom,(
    ! [A,B] : 
      ( ( equal(A,B)
        & environment(A) )
     => environment(B) )   )).

input_formula(greater_substitution_1,axiom,(
    ! [A,B,C] : 
      ( ( equal(A,B)
        & greater(A,C) )
     => greater(B,C) )   )).

input_formula(greater_substitution_2,axiom,(
    ! [A,B,C] : 
      ( ( equal(A,B)
        & greater(C,A) )
     => greater(C,B) )   )).

input_formula(greater_or_equal_substitution_1,axiom,(
    ! [A,B,C] : 
      ( ( equal(A,B)
        & greater_or_equal(A,C) )
     => greater_or_equal(B,C) )   )).

input_formula(greater_or_equal_substitution_2,axiom,(
    ! [A,B,C] : 
      ( ( equal(A,B)
        & greater_or_equal(C,A) )
     => greater_or_equal(C,B) )   )).

input_formula(in_environment_substitution_1,axiom,(
    ! [A,B,C] : 
      ( ( equal(A,B)
        & in_environment(A,C) )
     => in_environment(B,C) )   )).

input_formula(in_environment_substitution_2,axiom,(
    ! [A,B,C] : 
      ( ( equal(A,B)
        & in_environment(C,A) )
     => in_environment(C,B) )   )).

input_formula(subpopulations_substitution_1,axiom,(
    ! [A,B,C,D,E] : 
      ( ( equal(A,B)
        & subpopulations(A,C,D,E) )
     => subpopulations(B,C,D,E) )   )).

input_formula(subpopulations_substitution_2,axiom,(
    ! [A,B,C,D,E] : 
      ( ( equal(A,B)
        & subpopulations(C,A,D,E) )
     => subpopulations(C,B,D,E) )   )).

input_formula(subpopulations_substitution_3,axiom,(
    ! [A,B,C,D,E] : 
      ( ( equal(A,B)
        & subpopulations(C,D,A,E) )
     => subpopulations(C,D,B,E) )   )).

input_formula(subpopulations_substitution_4,axiom,(
    ! [A,B,C,D,E] : 
      ( ( equal(A,B)
        & subpopulations(C,D,E,A) )
     => subpopulations(C,D,E,B) )   )).

%----Problem axioms
%----L3. The difference between the disbanding rates of first movers and
%----efficient producers does not decrease.
input_formula(l3,axiom,(
    ! [E,T] : 
      ( ( environment(E)
        & subpopulations(first_movers,efficient_producers,E,T) )
     => ~ decreases(difference(disbanding_rate(first_movers,T),
disbanding_rate(efficient_producers,T))) )   )).

%----MP. The initial time point of the environment is the earliest time,
%----when both FM and EP are present in the environment.
input_formula(mp_earliest_time_point,axiom,(
    ! [E,T] : 
      ( environment(E)
     => ( ( in_environment(E,initial_FM_EP(E))
         => subpopulations(first_movers,efficient_producers,E,
initial_FM_EP(E)) )
        & ( subpopulations(first_movers,efficient_producers,E,T)
         => greater_or_equal(T,initial_FM_EP(E)) ) ) )   )).

%----MP. If f1(x1) > f2(x1) and f1(x)-f2(x) does not decrease on [x1,x2]
%----then f1(x2) > f2(x2).
%----INSTANTIATION: f1(x) = disbanding_rate(first_movers,x) ;
%----f2(x) = disbanding_rate(efficient_producers,x)
input_formula(mp_positive_function_difference,axiom,(
    ! [E,T,T1,T2] : 
      ( ( environment(E)
        & greater_or_equal(T,T1)
        & greater_or_equal(T2,T)
        & subpopulations(first_movers,efficient_producers,E,T2)
        & greater(disbanding_rate(first_movers,T1),
disbanding_rate(efficient_producers,T1)) )
     => ( ~ decreases(difference(disbanding_rate(first_movers,T),
disbanding_rate(efficient_producers,T)))
       => greater(disbanding_rate(first_movers,T2),
disbanding_rate(efficient_producers,T2)) ) )   )).

%----MP. If FM and EP are non-empty subpopulations at a time -point in the
%----environment, then this time point occurs while the environment
%----persists.
input_formula(mp_time_point_occurs,axiom,(
    ! [E,T] : 
      ( ( environment(E)
        & subpopulations(first_movers,efficient_producers,E,T) )
     => in_environment(E,T) )   )).

%----MP. The initial time of an environment cannot precede the opening of
%----this environment.
input_formula(mp_initial_time,axiom,(
    ! [E] : 
      ( environment(E)
     => greater_or_equal(initial_FM_EP(E),start_time(E)) )   )).

%----MP. If time point T1 occurs after the opening of the environment, and
%----a later time point T2 occurs before the environment ends, then T1 also
%----occurs before the end of the environment.
input_formula(mp_times_in_order,axiom,(
    ! [E,T1,T2] : 
      ( ( environment(E)
        & greater_or_equal(T1,start_time(E))
        & greater(T2,T1)
        & in_environment(E,T2) )
     => in_environment(E,T1) )   )).

%----MP. inequality
input_formula(mp_greater_transitivity,axiom,(
    ! [X,Y,Z] : 
      ( ( greater(X,Y)
        & greater(Y,Z) )
     => greater(X,Z) )   )).

%----MP. on "greater or equal to"
input_formula(mp_greater_or_equal,axiom,(
    ! [X,Y] : 
      ( greater_or_equal(X,Y)
     => ( greater(X,Y)
        | equal(X,Y) ) )   )).

%----A8. The disbanding rate of first movers exceeds the disbanding rate
%----of efficient producers initially.
input_formula(a8,hypothesis,(
    ! [E] : 
      ( environment(E)
     => greater(disbanding_rate(first_movers,initial_FM_EP(E)),
disbanding_rate(efficient_producers,initial_FM_EP(E))) )   )).

%----A10. If FM and EP are present in the environment at time-points t1
%----and t2, then they are present during the time-interval between 
%----t1 and t2.
input_formula(a10,hypothesis,(
    ! [E,T1,T2,T] : 
      ( ( environment(E)
        & subpopulations(first_movers,efficient_producers,E,T1)
        & subpopulations(first_movers,efficient_producers,E,T2)
        & greater_or_equal(T,T1)
        & greater_or_equal(T2,T) )
     => subpopulations(first_movers,efficient_producers,E,T) )   )).

%----GOAL: L2. The disbanding rate of first movers exceeds the disbanding
%----rate of efficient producers.
input_formula(prove_l2,conjecture,(
    ! [E,T] : 
      ( ( environment(E)
        & subpopulations(first_movers,efficient_producers,E,T) )
     => greater(disbanding_rate(first_movers,T),
disbanding_rate(efficient_producers,T)) )   )).
%--------------------------------------------------------------------------
