%--------------------------------------------------------------------------
% File     : MGT022+1 : TPTP v2.1.0. Released v2.0.0.
% Domain   : Management (Organisation Theory)
% Problem  : Decreasing resource availability affects FMS more than EPs
% Version  : [PB+94] axioms.
% English  : Decreasing resource availability affects the disbanding rate 
%            of first movers more than the disbanding rate of efficient 
%            producers.

% Refs     : [PM93]  Peli & Masuch (1993), The Logic of Propogation Strateg
%          : [PM94]  Peli & Masuch (1994), The Logic of Propogation Strateg
%          : [Kam95] Kamps (1995), Email to G. Sutcliffe
% Source   : [Kam95]
% Names    : LEMMA 4 [PM93]
%          : L4 [PB+94]

% Status   : theorem
% Rating   : ? v2.0.0
% Syntax   : Number of formulae    :    4 (   1 unit)
%            Number of atoms       :   16 (   0 equality)
%            Maximal formula depth :    6 (   4 average)
%            Number of connectives :   14 (   2 ~  ;   0  |;   5  &)
%                                         (   0 <=>;   7 =>;   0 <=)
%                                         (   0 <~>;   0 ~|;   0 ~&)
%            Number of predicates  :    6 (   0 propositional; 1-4 arity)
%            Number of functors    :    6 (   2 constant; 0-2 arity)
%            Number of variables   :    7 (   0 singleton;   7 !;   0 ?)
%            Maximal term depth    :    3 (   1 average)

% Comments : Same as version with [PM93] axioms.
%--------------------------------------------------------------------------
%----MP. If something is constant, then it does not decreases.
input_formula(mp_constant_not_decrease,axiom,(
    ! [X] : 
      ( constant(X)
     => ~ decreases(X) )   )).

%----A5. Less resilient subpopulations are more affected by decreasing
%----resource availability.
input_formula(a5,hypothesis,(
    ! [E,S1,S2,T] : 
      ( ( environment(E)
        & subpopulations(S1,S2,E,T)
        & greater(resilience(S2),resilience(S1)) )
     => ( ( decreases(resources(E,T))
         => increases(difference(disbanding_rate(S1,T),
disbanding_rate(S2,T))) )
        & ( constant(resources(E,T))
         => constant(difference(disbanding_rate(S1,T),
disbanding_rate(S2,T))) ) ) )   )).

%----A2. Efficient producers are more resilient than first movers.
input_formula(a2,hypothesis,(
    greater(resilience(efficient_producers),resilience(first_movers))   )).

%----GOAL: L4. A decreasing resource availability affects the disbanding 
%----rate of first movers more than the disbanding rate of efficient 
%----producers.
input_formula(prove_l4,conjecture,(
    ! [E,T] : 
      ( ( environment(E)
        & subpopulations(first_movers,efficient_producers,E,T) )
     => ( ( decreases(resources(E,T))
         => increases(difference(disbanding_rate(first_movers,T),
disbanding_rate(efficient_producers,T))) )
        & ( constant(resources(E,T))
         => ~ decreases(difference(disbanding_rate(first_movers,T),
disbanding_rate(efficient_producers,T))) ) ) )   )).
%--------------------------------------------------------------------------
