%--------------------------------------------------------------------------
% File     : MGT039+1 : TPTP v2.1.0. Released v2.0.0.
% Domain   : Management (Organisation Theory)
% Problem  : Selection favours EPs above Fms if change is slow
% Version  : [PB+94] axioms : Reduced & Augmented > Complete.
% English  : Selection favors efficient producers above first movers if
%            environmental change is slow. 

% Refs     : [PM93]  Peli & Masuch (1993), The Logic of Propogation Strateg
%          : [PM94]  Peli & Masuch (1994), The Logic of Propogation Strateg
%          : [Kam95] Kamps (1995), Email to G. Sutcliffe
% Source   : [Kam95]
% Names    : 

% Status   : theorem
% Rating   : ? v2.0.0
% Syntax   : Number of formulae    :   31 (   3 unit)
%            Number of atoms       :   92 (  26 equality)
%            Maximal formula depth :    9 (   3 average)
%            Number of connectives :   62 (   1 ~  ;   1  |;  30  &)
%                                         (   1 <=>;  29 =>;   0 <=)
%                                         (   0 <~>;   0 ~|;   0 ~&)
%            Number of predicates  :    9 (   0 propositional; 1-3 arity)
%            Number of functors    :    5 (   2 constant; 0-1 arity)
%            Number of variables   :   70 (   0 singleton;  69 !;   1 ?)
%            Maximal term depth    :    2 (   1 average)

% Comments : 
%--------------------------------------------------------------------------
%----Include equality axioms
include('Axioms/EQU001+0.ax').
%--------------------------------------------------------------------------
%----Subsitution axioms
input_formula(critical_point_substitution_1,axiom,(
    ! [A,B] : 
      ( equal(A,B)
     => equal(critical_point(A),critical_point(B)) )   )).

input_formula(end_time_substitution_1,axiom,(
    ! [A,B] : 
      ( equal(A,B)
     => equal(end_time(A),end_time(B)) )   )).

input_formula(start_time_substitution_1,axiom,(
    ! [A,B] : 
      ( equal(A,B)
     => equal(start_time(A),start_time(B)) )   )).

input_formula(environment_substitution_1,axiom,(
    ! [A,B] : 
      ( ( equal(A,B)
        & environment(A) )
     => environment(B) )   )).

input_formula(greater_substitution_1,axiom,(
    ! [A,B,C] : 
      ( ( equal(A,B)
        & greater(A,C) )
     => greater(B,C) )   )).

input_formula(greater_substitution_2,axiom,(
    ! [A,B,C] : 
      ( ( equal(A,B)
        & greater(C,A) )
     => greater(C,B) )   )).

input_formula(greater_or_equal_substitution_1,axiom,(
    ! [A,B,C] : 
      ( ( equal(A,B)
        & greater_or_equal(A,C) )
     => greater_or_equal(B,C) )   )).

input_formula(greater_or_equal_substitution_2,axiom,(
    ! [A,B,C] : 
      ( ( equal(A,B)
        & greater_or_equal(C,A) )
     => greater_or_equal(C,B) )   )).

input_formula(in_environment_substitution_1,axiom,(
    ! [A,B,C] : 
      ( ( equal(A,B)
        & in_environment(A,C) )
     => in_environment(B,C) )   )).

input_formula(in_environment_substitution_2,axiom,(
    ! [A,B,C] : 
      ( ( equal(A,B)
        & in_environment(C,A) )
     => in_environment(C,B) )   )).

input_formula(observational_period_substitution_1,axiom,(
    ! [A,B] : 
      ( ( equal(A,B)
        & observational_period(A) )
     => observational_period(B) )   )).

input_formula(propagation_strategy_substitution_1,axiom,(
    ! [A,B] : 
      ( ( equal(A,B)
        & propagation_strategy(A) )
     => propagation_strategy(B) )   )).

input_formula(selection_favors_substitution_1,axiom,(
    ! [A,B,C,D] : 
      ( ( equal(A,B)
        & selection_favors(A,C,D) )
     => selection_favors(B,C,D) )   )).

input_formula(selection_favors_substitution_2,axiom,(
    ! [A,B,C,D] : 
      ( ( equal(A,B)
        & selection_favors(C,A,D) )
     => selection_favors(C,B,D) )   )).

input_formula(selection_favors_substitution_3,axiom,(
    ! [A,B,C,D] : 
      ( ( equal(A,B)
        & selection_favors(C,D,A) )
     => selection_favors(C,D,B) )   )).

input_formula(slow_change_substitution_1,axiom,(
    ! [A,B] : 
      ( ( equal(A,B)
        & slow_change(A) )
     => slow_change(B) )   )).

%----Problem axioms
%----MP3. If selection favors organizations of a certain propagation
%----strategy, s1, above an other, s2, at the endpoints of all 
%----environments in the observational period, then it favors s1 above 
%----s2 during the whole observational period.  
%----Instantiation: EP = s1 ; FM = s2
input_formula(mp3_favoured_trategy,axiom,(
    ! [P] : 
      ( ( observational_period(P)
        & propagation_strategy(first_movers)
        & propagation_strategy(efficient_producers)
        & ! [E] : 
            ( ( environment(E)
              & in_environment(P,E) )
           => selection_favors(efficient_producers,first_movers,
end_time(E)) ) )
     => selection_favors(efficient_producers,first_movers,P) )   )).

%----MP4. If environmental change is slow during an observational period,
%----then all the environments in the observational period contain a
%----critical point.
input_formula(mp4_critical_point,axiom,(
    ! [P] : 
      ( ( observational_period(P)
        & slow_change(P) )
     => ! [E] : 
          ( ( environment(E)
            & in_environment(P,E) )
         => ? [T] : 
              ( in_environment(E,T)
              & greater(T,critical_point(E)) ) ) )   )).

%----MP. First movers and efficient producers are organizational sets of a
%----certain propagation strategy.
input_formula(mp_organizational_sets1,axiom,(
    propagation_strategy(first_movers)   )).

input_formula(mp_organizational_sets2,axiom,(
    propagation_strategy(efficient_producers)   )).

%----MP. If a time point occurs between the beginning and the end of the
%----environment, then it belongs to the environment.
input_formula(mp_time_in_environment,axiom,(
    ! [E,T] : 
      ( ( environment(E)
        & greater_or_equal(T,start_time(E))
        & greater_or_equal(end_time(E),T) )
     => in_environment(E,T) )   )).

%----MP. If a time point belongs to the environment, then the end-point of
%----the environment cannot precede it.
input_formula(mp_environment_end_point,axiom,(
    ! [E,T] : 
      ( ( environment(E)
        & in_environment(E,T) )
     => greater_or_equal(end_time(E),T) )   )).

%----MP. The critical point of an environment cannot precede the
%----environment's opening time.
input_formula(mp_time_of_critical_point,axiom,(
    ! [E] : 
      ( environment(E)
     => greater_or_equal(critical_point(E),start_time(E)) )   )).

%----MP. inequality
input_formula(mp_greater_transitivity,axiom,(
    ! [X,Y,Z] : 
      ( ( greater(X,Y)
        & greater(Y,Z) )
     => greater(X,Z) )   )).

%----MP. on "greater or equal to"
input_formula(mp_greater_or_equal,axiom,(
    ! [X,Y] : 
      ( greater_or_equal(X,Y)
    <=> ( greater(X,Y)
        | equal(X,Y) ) )   )).

%----MP. on beginning and ending times
input_formula(mp_beginning_and_ending,axiom,(
    ! [E,T] : 
      ( ( environment(E)
        & greater(T,start_time(E))
        & ~ greater(T,end_time(E)) )
     => greater_or_equal(end_time(E),T) )   )).

%----L8. Selection favors efficient producers above first movers past the
%----critical point.
input_formula(l8,hypothesis,(
    ! [E,T] : 
      ( ( environment(E)
        & in_environment(E,T)
        & greater(T,critical_point(E)) )
     => selection_favors(efficient_producers,first_movers,T) )   )).

%----GOAL: T8. Selection favors efficient producers above first movers if
%----environmental change is slow.
input_formula(prove_t8,conjecture,(
    ! [P] : 
      ( ( observational_period(P)
        & slow_change(P) )
     => selection_favors(efficient_producers,first_movers,P) )   )).
%--------------------------------------------------------------------------
