%--------------------------------------------------------------------------
% File     : MGT040+2 : TPTP v2.1.0. Released v2.0.0.
% Domain   : Management (Organisation Theory)
% Problem  : Selection favours FMs above EPs if change is not extreme
% Version  : [PM93] axioms.
% English  : Selection favors first movers above efficient producers if
%            environmental change is rapid but not extreme during the 
%            observational period. 

% Refs     : [PM93]  Peli & Masuch (1993), The Logic of Propogation Strateg
%          : [PM94]  Peli & Masuch (1994), The Logic of Propogation Strateg
%          : [Kam95] Kamps (1995), Email to G. Sutcliffe
% Source   : [PM93]
% Names    : Theorem 9* [Peli, et al., 1995]

% Status   : satisfiable
% Rating   : ? v2.0.0
% Syntax   : Number of formulae    :   36 (   3 unit)
%            Number of atoms       :  113 (  30 equality)
%            Maximal formula depth :    9 (   4 average)
%            Number of connectives :   85 (   8 ~  ;   1  |;  38  &)
%                                         (   0 <=>;  38 =>;   0 <=)
%                                         (   0 <~>;   0 ~|;   0 ~&)
%            Number of predicates  :   11 (   0 propositional; 1-3 arity)
%            Number of functors    :    6 (   3 constant; 0-2 arity)
%            Number of variables   :   78 (   0 singleton;  78 !;   0 ?)
%            Maximal term depth    :    2 (   1 average)

% Comments : 
%--------------------------------------------------------------------------
%----Include equality axioms
include('Axioms/EQU001+0.ax').
%--------------------------------------------------------------------------
%----Subsitution axioms
input_formula(appear_substitution_1,axiom,(
    ! [A,B,C] : 
      ( equal(A,B)
     => equal(appear(A,C),appear(B,C)) )   )).

input_formula(appear_substitution_2,axiom,(
    ! [A,B,C] : 
      ( equal(A,B)
     => equal(appear(C,A),appear(C,B)) )   )).

input_formula(critical_point_substitution_1,axiom,(
    ! [A,B] : 
      ( equal(A,B)
     => equal(critical_point(A),critical_point(B)) )   )).

input_formula(end_time_substitution_1,axiom,(
    ! [A,B] : 
      ( equal(A,B)
     => equal(end_time(A),end_time(B)) )   )).

input_formula(empty_substitution_1,axiom,(
    ! [A,B] : 
      ( ( equal(A,B)
        & empty(A) )
     => empty(B) )   )).

input_formula(environment_substitution_1,axiom,(
    ! [A,B] : 
      ( ( equal(A,B)
        & environment(A) )
     => environment(B) )   )).

input_formula(extreme_substitution_1,axiom,(
    ! [A,B] : 
      ( ( equal(A,B)
        & extreme(A) )
     => extreme(B) )   )).

input_formula(greater_substitution_1,axiom,(
    ! [A,B,C] : 
      ( ( equal(A,B)
        & greater(A,C) )
     => greater(B,C) )   )).

input_formula(greater_substitution_2,axiom,(
    ! [A,B,C] : 
      ( ( equal(A,B)
        & greater(C,A) )
     => greater(C,B) )   )).

input_formula(greater_or_equal_substitution_1,axiom,(
    ! [A,B,C] : 
      ( ( equal(A,B)
        & greater_or_equal(A,C) )
     => greater_or_equal(B,C) )   )).

input_formula(greater_or_equal_substitution_2,axiom,(
    ! [A,B,C] : 
      ( ( equal(A,B)
        & greater_or_equal(C,A) )
     => greater_or_equal(C,B) )   )).

input_formula(in_environment_substitution_1,axiom,(
    ! [A,B,C] : 
      ( ( equal(A,B)
        & in_environment(A,C) )
     => in_environment(B,C) )   )).

input_formula(in_environment_substitution_2,axiom,(
    ! [A,B,C] : 
      ( ( equal(A,B)
        & in_environment(C,A) )
     => in_environment(C,B) )   )).

input_formula(observational_period_substitution_1,axiom,(
    ! [A,B] : 
      ( ( equal(A,B)
        & observational_period(A) )
     => observational_period(B) )   )).

input_formula(propagation_strategy_substitution_1,axiom,(
    ! [A,B] : 
      ( ( equal(A,B)
        & propagation_strategy(A) )
     => propagation_strategy(B) )   )).

input_formula(rapid_change_substitution_1,axiom,(
    ! [A,B] : 
      ( ( equal(A,B)
        & rapid_change(A) )
     => rapid_change(B) )   )).

input_formula(selection_favors_substitution_1,axiom,(
    ! [A,B,C,D] : 
      ( ( equal(A,B)
        & selection_favors(A,C,D) )
     => selection_favors(B,C,D) )   )).

input_formula(selection_favors_substitution_2,axiom,(
    ! [A,B,C,D] : 
      ( ( equal(A,B)
        & selection_favors(C,A,D) )
     => selection_favors(C,B,D) )   )).

input_formula(selection_favors_substitution_3,axiom,(
    ! [A,B,C,D] : 
      ( ( equal(A,B)
        & selection_favors(C,D,A) )
     => selection_favors(C,D,B) )   )).

%----Problem axioms
%----MP3. If selection favors organizations of a certain propagation
%----strategy, s1, above an other, s2, at the endpoints of all 
%----environments in the observational period, then it favors s1 above 
%----s2 during the whole observational period.  
%----Instantiation: EP = s1 ; FM = s2
input_formula(mp3_favoured_trategy,axiom,(
    ! [P] : 
      ( ( observational_period(P)
        & propagation_strategy(first_movers)
        & propagation_strategy(efficient_producers)
        & ! [E] : 
            ( ( environment(E)
              & in_environment(P,E) )
           => selection_favors(efficient_producers,first_movers,
end_time(E)) ) )
     => selection_favors(efficient_producers,first_movers,P) )   )).

%----MP5. If environmental change is rapid during an observational 
%----period, then no environment in the observational period contains a 
%----critical point.
input_formula(mp5_rapid_change_is_non_critical,axiom,(
    ! [P] : 
      ( ( observational_period(P)
        & rapid_change(P) )
     => ! [E] : 
          ( ( environment(E)
            & in_environment(P,E) )
         => ~ in_environment(E,critical_point(E)) ) )   )).

%----MP6. If environmental change is not extreme during an observational
%----period, then no environment stays empty during this period.
input_formula(mp6_not_extreme_change_means_not_empty,axiom,(
    ! [P] : 
      ( ( observational_period(P)
        & ~ extreme(P) )
     => ! [E] : 
          ( ( environment(E)
            & in_environment(P,E) )
         => ~ empty(E) ) )   )).

%----MP. First movers and efficient producers are organizational sets of a
%----certain propagation strategy.
input_formula(mp_organizational_sets1,axiom,(
    propagation_strategy(first_movers)   )).

input_formula(mp_organizational_sets2,axiom,(
    propagation_strategy(efficient_producers)   )).

%----MP. The endpoint of an environment belongs to the environment.
input_formula(mp_endpoint_in_environment,axiom,(
    ! [E] : 
      ( environment(E)
     => in_environment(E,end_time(E)) )   )).

%----MP. The critical point can not occur before the environment opens.
input_formula(mp_critical_point_not_before_opening,axiom,(
    ! [E] : 
      ( ( environment(E)
        & ~ in_environment(E,critical_point(E)) )
     => greater(critical_point(E),end_time(E)) )   )).

%----MP. If an environment does not remain empty, then organizations appear
%----in it before it ends.
input_formula(mp_non_empty_means_organisations,axiom,(
    ! [E] : 
      ( ( environment(E)
        & ~ empty(E) )
     => greater_or_equal(end_time(E),appear(an_organisation,E)) )   )).

%----MP. If selection favors a group of organizations, s, until a certain
%----point of time in the environment, to, then selection would have also
%----favored "s" until the ending point of this environment if the
%----environment had closed before to was reached.
%----INSTANTIATION: s = FM ; to = critical_point(e)
input_formula(mp_selection_favours_in_time,axiom,(
    ! [E,T] : 
      ( ( environment(E)
        & greater_or_equal(T,appear(efficient_producers,E))
        & greater(critical_point(E),T)
        & ( in_environment(E,critical_point(E))
         => selection_favors(first_movers,efficient_producers,T) ) )
     => ( ~ in_environment(E,critical_point(E))
       => selection_favors(first_movers,efficient_producers
,end_time(E)) ) )   )).

%----MP. on "greater or equal to"
input_formula(mp_greater_or_equal,axiom,(
    ! [X,Y] : 
      ( greater_or_equal(X,Y)
     => ( greater(X,Y)
        | equal(X,Y) ) )   )).

%----MP. on appearance of EP
input_formula(mp_appearance_of_EP,axiom,(
    ! [E,T] : 
      ( ( in_environment(E,T)
        & ~ greater(appear(efficient_producers,E),T) )
     => greater_or_equal(T,appear(efficient_producers,E)) )   )).

%----T2. Selection favors first movers above efficient producers
%----between the appearence of first movers and the appearence of efficient
%----producers.
input_formula(t2,hypothesis,(
    ! [E,T] : 
      ( ( environment(E)
        & in_environment(E,T)
        & greater_or_equal(T,appear(first_movers,E))
        & greater(appear(efficient_producers,E),T) )
     => selection_favors(first_movers,efficient_producers,T) )   )).

%----T3. Selection favors first movers above efficient producers
%----between the appearence of efficient producers and the critical point.
input_formula(t3,hypothesis,(
    ! [E,T] : 
      ( ( environment(E)
        & in_environment(E,critical_point(E))
        & greater_or_equal(T,appear(efficient_producers,E))
        & greater(critical_point(E),T) )
     => selection_favors(first_movers,efficient_producers,T) )   )).

%----GOAL: T9. Selection favors first movers to efficient producers if
%----environmental change is rapid, provided that environmental change
%----during the observational period is not extreme.
input_formula(prove_t9,conjecture,(
    ! [P] : 
      ( ( observational_period(P)
        & rapid_change(P)
        & ~ extreme(P) )
     => selection_favors(first_movers,efficient_producers,P) )   )).
%--------------------------------------------------------------------------
